This is a convenience function that calls compare using object to create the true and test model specifications.
asymptotics(object, ...)Object of class compare.
Object of class distfreereg.
Additional arguments to pass to compare.
The fitted model in object is assumed to be the true model, not an estimation of the true model. Further, the simulation of values requires assuming a particular error distribution. See the "Warnings" section in compare's documentation for details.
Jesse Miller
An important step in implementing distfreereg is determining the plausibility that the sample size of a data set is adequate to produce the desired asymptotic behavior of the simulated statistics. This can be done by calling compare with the appropriate argument values. Because of the importance of this step, this convenience function automates that call using a single argument, namely the object of class distfreereg in question.
distfreereg, compare