distfreereg objectThis is a confint method for objects of class distfreereg. It calculates confidence intervals for the estimated parameters of a model in a distfreereg object.
# S3 method for distfreereg
confint(object, parm, level = 0.95, ...)The output from the appropriate confint method.
Object of class distfreereg.
Numeric or character vector; specifies which parameters are to be given confidence intervals. If missing, all parameters are considered.
Numeric vector of length one; specifies the confidence level.
Additional parameters passed to other methods. Currently ignored.
Jesse Miller
When object contains a model object (either in the test_mean or model element), then this model is sent to confint. Otherwise, object is sent to confint.default.
distfreereg, vcov.distfreereg, confint