formula.distfreereg: Extract formulas from distfreereg objects
Description
This is a formula method for objects of class distfreereg. It extracts the formula from a model in a distfreereg object.
Usage
# S3 method for distfreereg
formula(x, ...)
Value
Formula extracted from x$test_mean, or NULL if such a formula cannot be extracted.
Arguments
- x
Object of class distfreereg.
- ...
Additional parameters passed to or from other methods. Currently ignored.