distfreereg objectsThis is a print method for objects of class distfreereg.
# S3 method for distfreereg
print(x, ..., digits = 3, col_sep = 2, show_params = TRUE)No return value (NULL).
Object of class distfreereg.
Additional parameters, currently ignored.
Integer; passed to signif to determine the number of significant digits to display.
Integer; specifies the padding (in units of spaces) between columns in the printed table of statistics.
Logical; determines whether or not the parameter estimates, if present in x, are displayed.
Jesse Miller
This function prints a useful summary of the distfreereg object x.
distfreereg