distfreereg objectsThis is a vcov method for objects of class distfreereg. It calculates an estimated covariance matrix of the estimated parameters in a model from a distfreereg object.
# S3 method for distfreereg
vcov(object, ..., jacobian_args, hessian_args)Named numeric matrix equal to the estimated covariance matrix of the parameter estimates from object.
Object of class distfreereg.
Additional parameters passed to other methods when test_mean element of object is not of class function.
Lists of additional arguments to pass to jacobian and hessian.
This calculation can be computationally intensive when the sample size is large and object$test_mean is a function.
Jesse Miller
When the test_mean element of object is of class function, the covariance matrix is estimated using the method described in section 5.3 of Van der Vaart (2007). Otherwise, test_mean is of a class that has its own method for vcov, which is used to calculate the output.
Vaart, A. W. Asymptotic statistics, 2007, Cambridge series on statistical and probabilistic mathematics, Cambridge University Press.
distfreereg, confint.distfreereg